@@ -3,7 +3,10 @@ import logging
 import igraph as ig
 
 def layout_agents(scenario):
-    print("building layout")
+    if len(scenario.agents) == 0:
+        return
+
+    logging.info("building graph layout for {} agents".format(len(scenario.agents)))
     g = ig.Graph(directed=True)
 
     # add nodes
@@ -26,4 +29,4 @@ def layout_agents(scenario):
 
     for i, coord in enumerate(layout.coords):
         id = agent_ids[i]
-        scenario.agent(id).set_display_coords(coord[0], coord[1])
+        scenario.agent(id).set_display_xy(coord[0], coord[1])
