@@ -7,6 +7,7 @@ class Scenario:
     def __init__(self):
         self._agents = {}
         self._contracts = []
+        self._schema_name = ""
 
     @property
     def agents(self) -> typing.Dict[str, Agent]:
@@ -18,9 +19,9 @@ class Scenario:
 
     def add_agent(self, a):
         if a.id in self._agents:
-            otherAgentType = self._agents[a.id].type
+            other_agent_type_name = self._agents[a.id].type_name
             raise ValueError("can't add agent type '{}' because its id '{}' is already used by agent '{}'".format(
-                a.type, a.id, otherAgentType))
+                a.type_name, a.id, other_agent_type_name))
         self._agents[a.id] = a
 
     @property
@@ -30,10 +31,19 @@ class Scenario:
 
     def add_contract(self, c):
         if c.sender_id not in self._agents:
-            raise ValueError("can't add contract: invalid sender id '{}'".format(c.sender_id))
+            raise ValueError(
+                "can't add contract: invalid sender id '{}'".format(c.sender_id))
         if c.receiver_id not in self._agents:
-            raise ValueError("can't add contract: invalid receiver id '{}'".format(c.receiver_id))
+            raise ValueError(
+                "can't add contract: invalid receiver id '{}'".format(c.receiver_id))
 
         self._contracts.append(c)
         self._agents[c.sender_id].add_output(c.receiver_id)
         self._agents[c.receiver_id].add_input(c.sender_id)
+
+    @property
+    def schema_name(self) -> str:
+        return self._schema_name
+
+    def set_schema_name(self, schema_name: str):
+        self._schema_name = schema_name
