@@ -2,7 +2,7 @@ import logging
 import yaml
 
 
-def load_file(file_path):
+def must_load_file(file_path: str):
     """ Helper function to load the content of a YAML file """
     logging.debug("loading yaml file {}".format(file_path))
     try:
@@ -13,7 +13,7 @@ def load_file(file_path):
             "failed to load yaml file '{}'".format(file_path)) from e
 
 
-def save_to_file(dict, file_path):
+def save_to_file(dict, file_path: str):
     """ Helper function to save some content to a YAML file """
     logging.debug("saving yaml to file {}".format(file_path))
     try:
@@ -24,7 +24,7 @@ def save_to_file(dict, file_path):
             "failed to write data to yaml file '{}'".format(file_path)) from e
 
 
-def must_get_str_key(dict, key):
+def must_get_str_key(dict, key: str):
     """ Helper function to extract a YAML string key with a user friendly error message on failure """
     v = dict.get(key)
     if v is None:
@@ -32,7 +32,13 @@ def must_get_str_key(dict, key):
     return v
 
 
-def must_get_int_key(dict, key):
+def get_str_key_or(dict, key: str, default_value: str):
+    """ Helper function to extract a YAML string key if it exists, or return the given default value otherwise """
+    v = dict.get(key)
+    return default_value if v is None else v
+
+
+def must_get_int_key(dict, key: str):
     """ Helper function to extract a YAML int key with a user friendly error message on failure """
     v = must_get_str_key(dict, key)
     if not type(v) is int:
